| bcss_compute | R Documentation |
Function to Compute the Between-Cluster Sum of Squares (BCSS) for a Set of Clusters
bcss_compute(ncs, class_vec, clusters, q = seq(0.1, 0.9, by = 0.1))
ncs |
Vector of non-conformity scores |
class_vec |
Vector of class labels |
clusters |
List of clusters, where each element is a vector of class labels assigned to that cluster |
q |
Quantiles to use for the qECDFs, default is a sequence from 0.1 to 0.9 in steps of 0.1 |
A numeric value representing the BCSS for the clusters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.