| ch_index | R Documentation |
Function to Compute the Calinski-Harabasz Index for a Set of Clusters
ch_index(ncs, class_vec, clusters, q = seq(0.1, 0.9, by = 0.1))
ncs |
Vector of non-conformity scores |
class_vec |
Vector of class labels |
clusters |
List of clusters, where each element is a vector of class labels assigned to that cluster |
q |
Quantiles to use for the qECDFs, default is a sequence from 0.1 to 0.9 in steps of 0.1 |
A numeric value representing the Calinski-Harabasz index for the clusters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.