| class_to_clusters | R Documentation |
Function to Convert Class Vector to Cluster Vector Based on Calibrated Clusters
class_to_clusters(class_vec, cluster_vec_calib)
class_vec |
Vector of class labels |
cluster_vec_calib |
Vector of calibrated clusters |
A vector of cluster assignments, with attributes containing the clusters, method used, number of clusters, Calibrated Clustering index, and coverage gaps
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.