coverage_gap_finder: Function to Find the Coverage Gap for a Set of Clusters

View source: R/helpers.R

coverage_gap_finderR Documentation

Function to Find the Coverage Gap for a Set of Clusters

Description

Function to Find the Coverage Gap for a Set of Clusters

Usage

coverage_gap_finder(ncs, class_vec, cluster)

Arguments

ncs

Vector of non-conformity scores

class_vec

Vector of class labels

cluster

Vector of cluster labels

Value

A numeric value representing the maximum coverage gap between the clusters


pintervals documentation built on March 3, 2026, 5:06 p.m.