| dm_to_prob | R Documentation |
Function to Convert Distance Measure to Probability
dm_to_prob(dm, dms)
dm |
Distance measure |
dms |
Vector of distance measures for all clusters |
A numeric value representing the probability of the distance measure relative to the sum of all distance measures
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.