heterogeneous_error: Heterogeneous Error Function for Non-Conformity Scores

View source: R/helpers.R

heterogeneous_errorR Documentation

Heterogeneous Error Function for Non-Conformity Scores

Description

Heterogeneous Error Function for Non-Conformity Scores

Usage

heterogeneous_error(pred, truth, coefs)

Arguments

pred

a numeric vector of predicted values

truth

a numeric vector of true values

coefs

a numeric vector of coefficients for the heterogeneous error model. Must be of length 2, where the first element is the intercept and the second element is the slope.


pintervals documentation built on March 3, 2026, 5:06 p.m.