| kmeans_cluster_qecdf | R Documentation |
Function to Perform K-Means Clustering on Quantile Empirical Cumulative Distribution Functions (qECDFs) of Non-Conformity Scores
kmeans_cluster_qecdf(ncs, class_vec, q = seq(0.1, 0.9, by = 0.1), m)
ncs |
Vector of non-conformity scores |
class_vec |
Vector of class labels |
q |
Quantiles to use for the qECDFs, default is a sequence from 0.1 to 0.9 in steps of 0.1 |
m |
Number of clusters to form |
A list of clusters, where each element is a vector of class labels assigned to that cluster
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.