| ks_cluster | R Documentation |
Function to Perform Kolmogorov-Smirnov Clustering on Non-Conformity Scores
ks_cluster(ncs, class_vec, m, maxit = 100, nrep = 10)
ncs |
Vector of non-conformity scores |
class_vec |
Vector of class labels |
m |
Number of clusters to form |
maxit |
Maximum number of iterations for the clustering algorithm |
nrep |
Number of repetitions for the clustering algorithm |
A vector of cluster assignments, with attributes containing the clusters, coverage gaps, method used, number of clusters, and Calibrated Clustering index
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.