| ks_cluster_assignment_step | R Documentation |
Function to Assign Classes to Clusters Based on Kolmogorov-Smirnov Clustering
ks_cluster_assignment_step(ncs, class_vec, class_labels, clusters, m)
ncs |
Vector of non-conformity scores |
class_vec |
Vector of class labels |
class_labels |
Vector of unique class labels |
clusters |
List of clusters |
m |
Number of clusters |
A list of clusters, where each element is a vector of class labels assigned to that cluster
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.