ncs_compute: Non-Conformity Score Computation Function

View source: R/helpers.R

ncs_computeR Documentation

Non-Conformity Score Computation Function

Description

Non-Conformity Score Computation Function

Usage

ncs_compute(type, pred, truth, coefs = NULL)

Arguments

type

Type of non-conformity score to compute. Options include 'absolute_error', 'raw_error', 'relative_error', 'za_relative_error', and 'heterogeneous_error'.

pred

a numeric vector of predicted values

truth

a numeric vector of true values

coefs

a numeric vector of coefficients for the heterogeneous error model. Must be of length 2, where the first element is the intercept and the second element is the slope.


pintervals documentation built on March 3, 2026, 5:06 p.m.