validate_distance_inputs: Validate distance weighting inputs

View source: R/helpers.R

validate_distance_inputsR Documentation

Validate distance weighting inputs

Description

Internal helper to validate distance-related arguments used across conformal, bootstrap, mondrian, ccp, and bccp functions.

Usage

validate_distance_inputs(
  distance_features_calib,
  distance_features_pred,
  calib_length,
  pred_length,
  fn_name = "pinterval"
)

Arguments

distance_features_calib

Features for calibration set

distance_features_pred

Features for prediction set

calib_length

Expected number of calibration observations

pred_length

Expected number of prediction observations

fn_name

Name of the calling function, used in error messages

Value

NULL (called for side effects: stops on invalid input)


pintervals documentation built on March 3, 2026, 5:06 p.m.