za_rel_error: Zero-Adjusted Relative Error Function for Non-Conformity...

View source: R/helpers.R

za_rel_errorR Documentation

Zero-Adjusted Relative Error Function for Non-Conformity Scores by Predicted Values with a Small Adjustment

Description

Zero-Adjusted Relative Error Function for Non-Conformity Scores by Predicted Values with a Small Adjustment

Usage

za_rel_error(pred, truth)

Arguments

pred

a numeric vector of predicted values

truth

a numeric vector of true values

Value

a numeric vector of zero-adjusted relative errors


pintervals documentation built on March 3, 2026, 5:06 p.m.