Learn R Programming

pintervals (version 1.1.1)

class_to_clusters: Function to Convert Class Vector to Cluster Vector Based on Calibrated Clusters

Description

Function to Convert Class Vector to Cluster Vector Based on Calibrated Clusters

Usage

class_to_clusters(class_vec, cluster_vec_calib)

Value

A vector of cluster assignments, with attributes containing the clusters, method used, number of clusters, Calibrated Clustering index, and coverage gaps

Arguments

class_vec

Vector of class labels

cluster_vec_calib

Vector of calibrated clusters