| coverage_gap_finder | R Documentation |
Function to Find the Coverage Gap for a Set of Clusters
coverage_gap_finder(ncs, class_vec, cluster)
ncs |
Vector of non-conformity scores |
class_vec |
Vector of class labels |
cluster |
Vector of cluster labels |
A numeric value representing the maximum coverage gap between the clusters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.