Learn R Programming

pintervals (version 1.1.1)

coverage_gap_finder: Function to Find the Coverage Gap for a Set of Clusters

Description

Function to Find the Coverage Gap for a Set of Clusters

Usage

coverage_gap_finder(ncs, class_vec, cluster)

Value

A numeric value representing the maximum coverage gap between the clusters

Arguments

ncs

Vector of non-conformity scores

class_vec

Vector of class labels

cluster

Vector of cluster labels