| heterogeneous_error | R Documentation |
Heterogeneous Error Function for Non-Conformity Scores
heterogeneous_error(pred, truth, coefs)
pred |
a numeric vector of predicted values |
truth |
a numeric vector of true values |
coefs |
a numeric vector of coefficients for the heterogeneous error model. Must be of length 2, where the first element is the intercept and the second element is the slope. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.