Learn R Programming

pintervals (version 1.0.1)

kmeans_cluster_qecdf: Function to perform K-means clustering on quantile empirical cumulative distribution functions (qECDFs) of non-conformity scores

Description

Function to perform K-means clustering on quantile empirical cumulative distribution functions (qECDFs) of non-conformity scores

Usage

kmeans_cluster_qecdf(ncs, class_vec, q = seq(0.1, 0.9, by = 0.1), m)

Value

A list of clusters, where each element is a vector of class labels assigned to that cluster

Arguments

ncs

Vector of non-conformity scores

class_vec

Vector of class labels

q

Quantiles to use for the qECDFs, default is a sequence from 0.1 to 0.9 in steps of 0.1

m

Number of clusters to form