| ncs_compute | R Documentation |
Non-Conformity Score Computation Function
ncs_compute(type, pred, truth, coefs = NULL)
type |
Type of non-conformity score to compute. Options include 'absolute_error', 'raw_error', 'relative_error', 'za_relative_error', and 'heterogeneous_error'. |
pred |
a numeric vector of predicted values |
truth |
a numeric vector of true values |
coefs |
a numeric vector of coefficients for the heterogeneous error model. Must be of length 2, where the first element is the intercept and the second element is the slope. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.