za_rel_error: Zero-Adjusted Relative Error Function for Non-Conformity Scores by Predicted Values with a Small Adjustment
Description
Zero-Adjusted Relative Error Function for Non-Conformity Scores by Predicted Values with a Small Adjustment
Usage
za_rel_error(pred, truth)
Value
a numeric vector of zero-adjusted relative errors
Arguments
- pred
a numeric vector of predicted values
- truth
a numeric vector of true values